/*
 * Copyright (c) 2010, 2011 The University of Manchester, UK.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * * Neither the names of The University of Manchester nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package uk.org.taverna.server.client;

/**
 * An enum to represent the status of a Run on a Taverna Server.
 * 
 * @author Robert Haines
 */
public enum RunStatus {
	INITIALIZED("Initialized"), RUNNING("Operating"), FINISHED("Finished"), STOPPED(
			"Stopped"), UNDEFINED("unknown");

	private final String status;

	RunStatus(String status) {
		this.status = status;
	}

	/**
	 * Get the String representation of this instance.
	 * 
	 * @return the String representation of this instance.
	 */
	public String status() {
		return this.status;
	}

	/**
	 * Convert a String representation of a status to its RunStatus equivalent.
	 * 
	 * @param status
	 *            the status to convert.
	 * @return the converted status.
	 */
	public static RunStatus state(String status) {
		for (RunStatus rs : RunStatus.values()) {
			if (rs.status().equals(status)) {
				return rs;
			}
		}

		return RunStatus.UNDEFINED;
	}
}
